#!/bin/sh
#run this after 2modules.sh
#141207 copy 4convert-kernel-source-sfs-to-pet
#150326 copy 1recompile.sh
#160413 fix 'build' and 'source' symlinks.
#170305 test if 4convert-kernel-source-sfs-to-pet exists.
#190722 change name kernel_src-${KERNELVERSION}${POSTVER}-patched.sfs to kernel_${KERNELVERSION}${POSTVER}-p1_src.sfs
#190722 meta-data in kernel src sfs.
#20201007 fix.
#20210426 use pngoverlay-cairo
#20220306 $TODAYDATE into PET and SFS names.
#20220516 make sure TODAYDATE same all scripts.
#20231020 fix src sfs for usr-merge.

. /etc/DISTRO_SPECS
KERNELVERSION="`uname -r`"
[ ! -d linux-${KERNELVERSION} ] && exit
#TODAYDATE="`date +%Y%m%d`" #20220306
TODAYDATE="$(cat TODAYDATE)" #20220516

DASHOUT="`find /usr/src -maxdepth 1 -type d -name "out-k${KERNELVERSION}-*"`"
if [ "$DASHOUT" ];then
 POSTVER="-`echo -n "$DASHOUT" | rev | cut -f 1 -d '-' | rev`" #ex: -43
else
 POSTVER=""
fi

#clean...
cd linux-${KERNELVERSION}
make clean
make prepare
sync
cd ..

#finish off...
cp -f 1kernel.sh out-k${KERNELVERSION}${POSTVER}/
cp -f 1recompile.sh out-k${KERNELVERSION}${POSTVER}/ #150326
cp -f 2modules.sh out-k${KERNELVERSION}${POSTVER}/
cp -f 3package.sh out-k${KERNELVERSION}${POSTVER}/
[ -f ./4convert-kernel-source-sfs-to-pet ] && cp -f 4convert-kernel-source-sfs-to-pet out-k${KERNELVERSION}${POSTVER}/ #141207 170305
sync
echo "Creating kernel source sfs..."
rm -rf kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src 2> /dev/null
mkdir kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src
mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/src
mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/lib/modules/${KERNELVERSION} #20231020
cp -a -f linux-${KERNELVERSION} kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/src/
ln -s linux-${KERNELVERSION} kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/src/linux

#160413 fix 'build' and 'source' symlinks, when /usr/src is a symlink to another partition...
#cp -a -f /lib/modules/${KERNELVERSION}/build kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/lib/modules/${KERNELVERSION}/
#cp -a -f /lib/modules/${KERNELVERSION}/source kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/lib/modules/${KERNELVERSION}/
ln -s /usr/src/linux-${KERNELVERSION} kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/lib/modules/${KERNELVERSION}/build #20231020
ln -s /usr/src/linux-${KERNELVERSION} kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/lib/modules/${KERNELVERSION}/source #20231020

#190722 put some stuff inside, new easyos sfs format...
echo "Creating meta-data for kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs ..."
SIZEK="$(du -s -k kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src | cut -f 1)"
echo "#generated by 3package.sh:
DB_pkgname='kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}'
DB_nameonly='kernel'
DB_version='${KERNELVERSION}${POSTVER}'
DB_revision='${TODAYDATE}'
DB_arch='src'
DB_categories='Utility'
DB_size='${SIZEK}'
DB_fullfilename='kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs'
DB_dependencies='devx,easy'
DB_description='Linux kernel ${KERNELVERSION}${POSTVER} source'
DB_description_long='This is the kernel source. In a layered filesystem with the devx and easy SFS files underneath, the kernel may be recompiled, or extra modules compiled.'
DB_compileddistro='${DISTRO_BINARY_COMPAT}'
DB_compiledrelease='${DISTRO_COMPAT_VERSION}'
DB_path='easyos/${DISTRO_BINARY_COMPAT}/${DISTRO_COMPAT_VERSION}'
DB_apps='kernel'
DB_icons='kernel'
DB_install='individual'
DB_hash=''" > out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.specs

mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/.control
cp -a -f out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.specs kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/.control/kernel.specs
cp -a -f /usr/local/lib/X11/pixmaps/ec-overlay48.png ./

if which pngoverlay-cairo >/dev/null;then #20210426
 pngoverlay-cairo kernel48.png ec-overlay48.png ec-kernel48.png
else
 #cp -f /usr/sbin/pngoverlay ./ #20201007
 ./pngoverlay kernel48.png ec-overlay48.png ec-kernel48.png
fi

mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/pixmaps
cp -f kernel48.png kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/pixmaps/
cp -f kernel48.png kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/pixmaps/kernel.png
cp -f ec-kernel48.png kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/pixmaps/
cp -f kernel48.png out-k${KERNELVERSION}${POSTVER}/kernel.png
#dummy .desktop...
mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/applications
echo "[Desktop Entry]
NoDisplay=true
Name=kernel
Exec=ec-chroot-kernel
Icon=container48.png
Categories=X-Utility" > kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/share/applications/kernel.desktop
#run script...
mkdir -p kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/bin #20231020
echo "#!/bin/sh
empty -f ec-chroot kernel sakura" > kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/bin/ec-chroot-kernel #20231020
chmod 755 kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src/usr/bin/ec-chroot-kernel #20231020
#***NOTICE*** haven't created .control/kernel.configuration
if [ -f out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs ];then
 rm -f out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs
fi

sync
mksquashfs4 kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs
sync
chmod 644 out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs

#190722
HASH="$(sha256sum out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.sfs | cut -f 1 -d ' ')"
sed -i -e "s%^DB_hash=.*%DB_hash='${HASH}'%" out-k${KERNELVERSION}${POSTVER}/kernel_${KERNELVERSION}${POSTVER}-${TODAYDATE}_src.specs

#create pet
echo "Finished, however you can do one more thing..."
echo -n "Press ENTER to create PET, any other char to quit: "
read shalliquit
[ "$shalliquit" != "" ] && exit
echo
echo "The PET package will be named something like"
echo "'linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-pae-i686-w5.pet'"
echo -n "Type a string for the 'pae-i686-w5' part: "
read PETPOSTSTR
rm -rf linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}
mkdir linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}
mkdir linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/boot
mkdir -p linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/etc/modules
mkdir -p linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/modules

cp -f out-k${KERNELVERSION}${POSTVER}/System.map linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/boot/
cp -f out-k${KERNELVERSION}${POSTVER}/vmlinuz linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/boot/
cp -f out-k${KERNELVERSION}${POSTVER}/DOTconfig-${KERNELVERSION}${POSTVER} linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/etc/modules/
cp -f out-k${KERNELVERSION}${POSTVER}/modules.builtin linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/etc/modules/ 2>/dev/null #<=2.6.32 does not have this.
cp -f out-k${KERNELVERSION}${POSTVER}/modules.order linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/etc/modules/

cp -f out-k${KERNELVERSION}${POSTVER}/firmware.tar.gz linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/
cd linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib
tar -zxf firmware.tar.gz
sync
rm -f firmware.tar.gz
cd ../../

cp -f out-k${KERNELVERSION}${POSTVER}/${KERNELVERSION}.tar.gz linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/modules/
cd linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/modules
tar -zxf ${KERNELVERSION}.tar.gz
sync
rm -f ${KERNELVERSION}.tar.gz
rm -f ${KERNELVERSION}/build
rm -f ${KERNELVERSION}/source
rm -f ${KERNELVERSION}/modules.*
cd ../../
DB_size="`du -k -s | cut -f 1`"
cd ../

#mkdir linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/modules/${KERNELVERSION}/misc
#cp -f out-k${KERNELVERSION}${POSTVER}/${NDISWRAPPERDIR}-i486/lib/modules/${KERNELVERSION}/misc/ndiswrapper.ko linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/lib/modules/${KERNELVERSION}/misc/

#ex: linux_kernel-2.6.39-3-pae-i686-1-w5|linux_kernel|2.6.39-3-pae-i686-1-w5||BuildingBlock|65772K||linux_kernel-2.6.39-3-pae-i686-1-w5.pet||Linux kernel 2.6.39-3 compiled in Wary with gcc 4.3.4, smp-enabled, has usb-storage patch, pae-enabled, i686 Pentium-Pro and later CPU, does not support isa bus|puppy|wary5||
echo "linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}|linux_kernel|${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}||BuildingBlock|${DB_size}K||linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}.pet||Linux kernel ${KERNELVERSION}${POSTVER} compiled in ${DISTRO_NAME} version ${DISTRO_VERSION}|${DISTRO_BINARY_COMPAT}|${DISTRO_COMPAT_VERSION}||" > linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}/pet.specs
sync

dir2tgz linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}
sync
tgz2pet linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}.tar.gz
sync
mv -f linux_kernel-${KERNELVERSION}${POSTVER}-${TODAYDATE}-${PETPOSTSTR}.pet out-k${KERNELVERSION}${POSTVER}/
sync

echo "Finished"
###END###

